@@ -1,4 +1,3 @@
-import os
 import kopf
 
 import digi.util as util
@@ -8,12 +7,14 @@ from digi.mount import Mounter
 def run():
     import digi
 
-    # run mounter
-    if os.environ.get("MOUNTER", "false") == "true":
+    # mounter
+    if digi.enable_mounter:
         Mounter(digi.g, digi.v, digi.r, digi.n, digi.ns,
                 log_level=digi.log_level).start()
+    # pool client
+    digi.pool = digi.data.create_pool()
 
-    # kopf embedded operator
+    # reconciler
     _model = {
         "group": digi.g,
         "version": digi.v,
@@ -38,27 +39,38 @@ def run():
     # reconciler operations
     from digi.reconcile import rc
     from digi.view import CleanView
-    _trim_mount = os.environ.get("PARENT_TRIM_MOUNT", True)
-
-    # TBD selectively add decorator
     @kopf.on.create(**_model, **_kwargs)
     @kopf.on.resume(**_model, **_kwargs)
     @kopf.on.update(**_model, **_kwargs)
     def reconcile(spec, meta, *args, **kwargs):
+        digi.logger.debug(f"processing gen: {meta['generation']}; "
+                          f"resource version: {meta['resourceVersion']}; "
+                          f"skip_gen: {rc.skip_gen}; "
+                          f"last_seen_gen: {rc.last_seen_gen}; "
+                          f"reconcile count: {rc.count}")
+
+        gen = meta["generation"]
+        if gen == rc.last_seen_gen:
+            digi.logger.info(f"skipped gen {gen} due to last-seen")
+            return
+
+        rc.last_seen_gen = gen
+        rc.count += 1
+
         if digi.pool is not None:
             try:
-                digi.pool.load([
-                    CleanView(dict(spec), trim_mount=_trim_mount).m(),
-                ])
-                digi.logger.info(f"Done loading model snapshot to pool.")
+                model = CleanView(dict(spec),
+                                  trim_mount=digi.load_trim_mount).m()
+                model["_type"] = "model"
+                digi.pool.load([model])
+                digi.logger.info(f"done loading model snapshot to pool")
             except Exception as e:
                 digi.logger.warning(f"unable to load to pool: {e}")
 
-        gen = meta["generation"]
         # skip the last self-write
         # TBD for parallel reconciliation may need to lock rc.gen before patch
         if gen == rc.skip_gen:
-            digi.logger.info(f"Skipping gen {gen}")
+            digi.logger.info(f"skipped gen {gen} due to self-write")
             return
 
         spec = rc.run(spec, *args, **kwargs)
@@ -66,25 +78,40 @@ def run():
                                                    spec, gen=gen)
         if e is not None:
             if e.status == util.DriverError.GEN_OUTDATED:
-                # retry s.t. the diff object contains the past changes
-                # TBD(@kopf) non-zero delay fix
-                # raise kopf.TemporaryError(e, delay=0)
-                digi.logger.warning("gen outdated")
+                digi.logger.warning(f"gen {gen} outdated; "
+                                    f"pending {len(rc._pending_handler)} handlers")
                 return
             else:
                 raise kopf.PermanentError(e.status)
 
-        # if the model didn't get updated do not
-        # increment the counter
+        # if the model isn't updated do not
+        # increment the skip marker
         new_gen = resp["metadata"]["generation"]
         if gen + 1 == new_gen:
             rc.skip_gen = new_gen
+
         rc.clear_pending()
-        digi.logger.info(f"Done reconciliation")
+        digi.logger.info(f"done reconciliation")
 
     @kopf.on.delete(**_model, **_kwargs, optional=True)
     def on_delete(*args, **kwargs):
         _, _ = args, kwargs
-        # _stop.set()
+        _stop.set()
 
+    if digi.enable_visual:
+        import os, sys, subprocess
+        try:
+            subprocess.check_call(f"python visual.py &",
+                                  env={**os.environ.copy(), **{
+                                      "MOUNTER": "false",
+                                      "VISUAL": "false",
+                                      "LOGGER_NAME": "digi.visual",
+                                  }},
+                                  shell=True)
+            digi.logger.info("started visualizer")
+        except subprocess.CalledProcessError:
+            digi.logger.fatal("unable to start visualizer")
+            sys.exit(1)
+
+    # TBD graceful termination
     _ready, _stop = util.run_operator(_registry, log_level=digi.log_level)
