@@ -3,7 +3,6 @@ import sys
 import logging
 from collections import defaultdict
 import kopf
-from kopf.engines import loggers
 
 import digi.util as util
 from digi.util import parse_gvr, spaced_name, parse_spaced_name
@@ -86,24 +85,24 @@ class Mounter:
 
         """ children event handlers """
 
-        def on_child_create(body, *args, **kwargs):
-            _, _ = args, kwargs
+        def on_child_create(body, meta, name, *args, **kwargs):
             _g, _v, _r = util.gvr_from_body(body)
-            _sync_from_parent(_g, _v, _r,
+            self._logger.info(f"on create child {name} gen {meta['generation']}")
+            _sync_from_parent(_g, _v, _r, meta=meta, name=name,
                               attrs_to_trim=TRIM_FROM_PARENT,
                               *args, **kwargs)
-            _sync_to_parent(_g, _v, _r,
+            _sync_to_parent(_g, _v, _r, meta=meta, name=name,
                             attrs_to_trim=TRIM_FROM_CHILD,
                             *args, **kwargs)
 
         def on_child_update(body, meta, name, namespace,
                             *args, **kwargs):
-            _, _ = args, kwargs
-
             _g, _v, _r = util.gvr_from_body(body)
             _id = util.model_id(_g, _v, _r, name, namespace)
 
+            self._logger.info(f"on child {name} gen {meta['generation']}")
             if meta["generation"] == self._children_skip_gen.get(_id, -1):
+                self._logger.info(f"skipped child {name} gen {meta['generation']}")
                 return
 
             return _sync_to_parent(_g, _v, _r, name, namespace, meta,
@@ -142,7 +141,7 @@ class Mounter:
             if (gvr_str not in mounts or
                     (nsn_str not in mounts[gvr_str] and
                      name not in mounts[gvr_str])):
-                self._logger.warning(f"Unable to find the {nsn_str} or {name} in the {parent}")
+                self._logger.warning(f"unable to find the {nsn_str} or {name} in the {parent}")
                 return
 
             models = mounts[gvr_str]
@@ -159,7 +158,7 @@ class Mounter:
             )
 
             if e is not None:
-                self._logger.warning(f"Unable to sync from parent due to {e}")
+                self._logger.warning(f"unable to sync from parent to {name} due to {e}")
             else:
                 model_id = util.model_id(group, version, plural,
                                          name, namespace)
@@ -233,12 +232,14 @@ class Mounter:
                 # continue to try until succeed
                 resp, e = util.patch_spec(g, v, r, n, ns, parent_patch, rv=prv)
                 if e is not None:
-                    self._logger.warning(f"Failed to sync to parent due to {e}")
-                    if e.status != 409:
+                    if e.status == 409:
+                        self._logger.warning(f"unable to sync to parent from {name} due to conflict; retry")
+                    else:
+                        self._logger.error(f"failed to sync {name} to parent due to {e}; abort")
                         return
-                    # time.sleep(1)
                 else:
                     new_gen = resp["metadata"]["generation"]
+                    self._logger.info(f"update child {name} generation to {meta['generation']}")
                     if pgn + 1 == new_gen:
                         self._parent_skip_gen = new_gen
                     break
@@ -265,6 +266,7 @@ class Mounter:
             _, _ = args, kwargs
 
             if meta["generation"] == self._parent_skip_gen:
+                self._logger.info(f"skipped parent gen {self._parent_skip_gen}")
                 return
 
             mounts = spec.get("mount", {})
@@ -273,6 +275,10 @@ class Mounter:
             _sync_to_children(spec, diff)
             _prune_mounts(mounts, meta)
 
+        def on_parent_delete(*args, **kwargs):
+            _, _ = args, kwargs
+            self.stop()
+
         def _prune_mounts(mounts, meta):
             rv = meta["resourceVersion"]
             while True:
@@ -289,20 +295,16 @@ class Mounter:
                 }
                 _, e = util.patch_spec(g, v, r, n, ns, patch, rv=rv)
                 if e is None:
-                    self._logger.info(f"Prune mount: {patch}")
+                    self._logger.info(f"prune mount: {patch}")
                     return
                 elif e.status != 409:
-                    self._logger.warning(f"Prune mount failed due to {e}")
+                    self._logger.warning(f"prune mount failed due to {e}")
                     return
 
-                self._logger.info(f"Prune mount will retry due to: {e}")
+                self._logger.info(f"prune mount will retry due to: {e}")
                 spec, rv, _ = util.get_spec(g, v, r, n, ns)
                 mounts = spec.get("mount", {})
 
-        def on_parent_delete(*args, **kwargs):
-            _, _ = args, kwargs
-            self.stop()
-
         def _update_children_watches(mounts: dict):
             # iterate over mounts and add/trim child event watches
             # add watches
@@ -319,6 +321,7 @@ class Mounter:
                         continue
 
                     # TBD: add child event handlers
+                    self._logger.info(f"new watch for child {nsn_str}")
                     self._children_watches[gvr_str][nsn_str] \
                         = Watch(*gvr, *nsn,
                                 create_fn=on_child_create,
@@ -398,7 +401,7 @@ class Mounter:
                     spec=cs,
                     gen=max(gen, self._children_gen.get(model_id, -1)))
                 if e is not None:
-                    self._logger.warning(f"Unable to sync to children due to {e}")
+                    self._logger.warning(f"unable to sync to child {model_id} due to {e}")
                 else:
                     new_gen = resp["metadata"]["generation"]
                     self._children_gen[model_id] = new_gen
@@ -430,13 +433,9 @@ class Mounter:
         self._logger = logging.getLogger(__name__)
         self._logger.setLevel(log_level)
 
-        _handler = logging.StreamHandler()
-        _handler.setFormatter(loggers.make_formatter())
-        self._logger.addHandler(_handler)
-
     def start(self):
         self._parent_watch.start()
-        self._logger.info("Started the mounter")
+        self._logger.info("started the mounter")
 
     def stop(self):
         self._parent_watch.stop()
